@@ -1,6 +1,6 @@
 /*
  * gaim - Gadu-Gadu Protocol Plugin
- * $Id: gg.c,v 1.28 2002/12/11 02:09:43 lschiere Exp $
+ * $Id: gg.c,v 1.37 2003/01/28 21:42:13 seanegan Exp $
  *
  * Copyright (C) 2001 Arkadiusz Mikiewicz <misiek@pld.ORG.PL>
  * 
@@ -45,6 +45,7 @@
 /* Library from EKG (Eksperymentalny Klient Gadu-Gadu) */
 #include "libgg.h"
 #include "multi.h"
+#include "core.h"
 #include "prpl.h"
 #include "gaim.h"
 #include "proxy.h"
@@ -89,7 +90,7 @@
 
 /* for win32 compatability */
 G_MODULE_IMPORT GSList *connections;
-
+G_MODULE_IMPORT GSList *groups;
 
 struct agg_data {
 	struct gg_session *sess;
@@ -129,7 +130,7 @@ static gint args_compare(gconstpointer a, gconstpointer b)
 
 static gboolean allowed_uin(struct gaim_connection *gc, char *uin)
 {
-	switch (gc->permdeny) {
+	switch (gc->user->permdeny) {
 	case 1:
 		/* permit all, deny none */
 		return TRUE;
@@ -140,13 +141,13 @@ static gboolean allowed_uin(struct gaim_connection *gc, char *uin)
 		break;
 	case 3:
 		/* permit some. */
-		if (g_slist_find_custom(gc->permit, uin, args_compare))
+		if (g_slist_find_custom(gc->user->permit, uin, args_compare))
 			return TRUE;
 		return FALSE;
 		break;
 	case 4:
 		/* deny some. */
-		if (g_slist_find_custom(gc->deny, uin, args_compare))
+		if (g_slist_find_custom(gc->user->deny, uin, args_compare))
 			return FALSE;
 		return TRUE;
 		break;
@@ -194,32 +195,35 @@ static void agg_set_away(struct gaim_connection *gc, char *state, char *msg)
 	struct agg_data *gd = (struct agg_data *)gc->proto_data;
 	int status = gd->own_status;
 
-	if (gc->away)
+	if (gc->away) {
+		g_free(gc->away);
 		gc->away = NULL;
+	}
 
 	if (!g_strcasecmp(state, AGG_STATUS_AVAIL))
 		status = GG_STATUS_AVAIL;
-	else if (!g_strcasecmp(state, AGG_STATUS_AVAIL_FRIENDS))
+	else if (!g_strcasecmp(state, AGG_STATUS_AVAIL_FRIENDS)) {
 		status = GG_STATUS_AVAIL | GG_STATUS_FRIENDS_MASK;
-	else if (!g_strcasecmp(state, AGG_STATUS_BUSY)) {
+		gc->away = g_strdup("");
+	} else if (!g_strcasecmp(state, AGG_STATUS_BUSY)) {
 		status = GG_STATUS_BUSY;
-		gc->away = "";
+		gc->away = g_strdup("");
 	} else if (!g_strcasecmp(state, AGG_STATUS_BUSY_FRIENDS)) {
 		status =  GG_STATUS_BUSY | GG_STATUS_FRIENDS_MASK;
-		gc->away = "";
+		gc->away = g_strdup("");
 	} else if (!g_strcasecmp(state, AGG_STATUS_INVISIBLE)) {
 		status = GG_STATUS_INVISIBLE;
-		gc->away = "";
+		gc->away = g_strdup("");
 	} else if (!g_strcasecmp(state, AGG_STATUS_INVISIBLE_FRIENDS)) {
 		status = GG_STATUS_INVISIBLE | GG_STATUS_FRIENDS_MASK;
-		gc->away = "";
+		gc->away = g_strdup("");
 	} else if (!g_strcasecmp(state, AGG_STATUS_NOT_AVAIL)) {
 		status = GG_STATUS_NOT_AVAIL;
-		gc->away = "";
+		gc->away = g_strdup("");
 	} else if (!g_strcasecmp(state, GAIM_AWAY_CUSTOM)) {
 		if (msg) {
 			status = GG_STATUS_BUSY;
-			gc->away = "";
+			gc->away = g_strdup("");
 		} else
 			status = GG_STATUS_AVAIL;
 
@@ -274,7 +278,7 @@ static GList *agg_buddy_menu(struct gaim_connection *gc, char *who)
 {
 	GList *m = NULL;
 	struct proto_buddy_menu *pbm;
-	struct buddy *b = find_buddy(gc, who);
+	struct buddy *b = find_buddy(gc->user, who);
 	static char buf[AGG_BUF_LEN];
 
 	if (!b) {
@@ -302,7 +306,7 @@ static void main_callback(gpointer data, gint source, GaimInputCondition cond)
 	if (gd->sess->fd != source)
 		gd->sess->fd = source;
 
-	if (source == -1) {
+	if (source != 0) {
 		hide_login_progress(gc, _("Could not connect"));
 		signoff(gc);
 		return;
@@ -396,7 +400,7 @@ static void main_callback(gpointer data, gint source, GaimInputCondition cond)
 		}
 		break;
 	case GG_EVENT_ACK:
-		debug_printf("main_callback: message %d to %u sent with status %d\n",
+		debug_printf("main_callback: message %d to %lu sent with status %d\n",
 			     e->event.ack.seq, e->event.ack.recipient, e->event.ack.status);
 		break;
 	default:
@@ -418,15 +422,15 @@ void login_callback(gpointer data, gint source, GaimInputCondition cond)
 		return;
 	}
 	debug_printf("Found GG connection\n");
-	if (gd->sess->fd != source) {
-		gd->sess->fd = source;
-		debug_printf("Setting sess->fd to source\n");
-	}
-	if (source == -1) {
+	
+	if (source != 0) {
 		hide_login_progress(gc, _("Unable to connect."));
 		signoff(gc);
 		return;
 	}
+
+	gd->sess->fd = source;
+
 	debug_printf("Source is valid.\n");
 	if (gc->inpa == 0) {
 		debug_printf("login_callback.. checking gc->inpa .. is 0.. setting fd watch\n");
@@ -471,9 +475,8 @@ void login_callback(gpointer data, gint source, GaimInputCondition cond)
 			gaim_input_remove(gc->inpa);
 
 			ip.s_addr = gd->sess->server_ip;
-			gd->sess->fd = proxy_connect(inet_ntoa(ip), gd->sess->port, login_callback, gc);
 			
-			if (gd->sess->fd < 0) {
+			if (proxy_connect(inet_ntoa(ip), gd->sess->port, login_callback, gc) < 0) {
 				g_snprintf(buf, sizeof(buf), _("Connect to %s failed"), inet_ntoa(ip));
 				hide_login_progress(gc, buf);
 				signoff(gc);
@@ -504,8 +507,6 @@ void login_callback(gpointer data, gint source, GaimInputCondition cond)
 		account_online(gc);
 		serv_finish_login(gc);
 
-		if (bud_list_cache_exists(gc))
-			do_import(gc, NULL);
 		break;
 	case GG_EVENT_CONN_FAILED:
 		gaim_input_remove(gc->inpa);
@@ -571,9 +572,7 @@ static void agg_login(struct aim_user *user)
 	gd->sess->state = GG_STATE_CONNECTING;
 	gd->sess->check = GG_CHECK_WRITE;
 	gd->sess->async = 1;
-	gd->sess->fd = proxy_connect(GG_APPMSG_HOST, GG_APPMSG_PORT, login_callback, gc);
-
-	if (gd->sess->fd < 0) {
+	if (proxy_connect(GG_APPMSG_HOST, GG_APPMSG_PORT, login_callback, gc) < 0) {
 		g_snprintf(buf, sizeof(buf), _("Connect to %s failed"), GG_APPMSG_HOST);
 		hide_login_progress(gc, buf);
 		signoff(gc);
@@ -786,7 +785,7 @@ static void import_buddies_server_results(struct gaim_connection *gc, gchar *web
 		g_strdelimit(users_tbl[i], "\r\t\n\015", ' ');
 		data_tbl = g_strsplit(users_tbl[i], ";", 8);
 
-		show = data_tbl[3];
+		show = charset_convert(data_tbl[3], "CP1250", "UTF-8");
 		name = data_tbl[6];
 
 		if (invalid_uin(name)) {
@@ -794,7 +793,7 @@ static void import_buddies_server_results(struct gaim_connection *gc, gchar *web
 		}
 
 		debug_printf("import_buddies_server_results: uin: %s\n", name);
-		if (!find_buddy(gc, name)) {
+		if (!find_buddy(gc->user, name)) {
 			/* Default group if none specified on server */
 			gchar *group = g_strdup("Gadu-Gadu");
 			if (strlen(data_tbl[5])) {
@@ -806,10 +805,11 @@ static void import_buddies_server_results(struct gaim_connection *gc, gchar *web
 				g_strfreev(group_tbl);
 			}
 			/* Add Buddy to our userlist */
-			add_buddy(gc, group, name, strlen(show) ? show : name);
-			do_export(gc);
+			add_buddy(gc->user, group, name, strlen(show) ? show : name);
+			gaim_blist_save();
 			g_free(group);
 		}
+		g_free(show);
 		g_strfreev(data_tbl);
 	}
 	g_strfreev(users_tbl);
@@ -934,7 +934,7 @@ static void http_req_callback(gpointer data, gint source, GaimInputCondition con
 		return;
 	}
 
-	if (source == -1) {
+	if (source != 0) {
 		g_free(request);
 		g_free(hdata);
 		return;
@@ -1000,7 +1000,7 @@ static void export_buddies_server(struct gaim_connection *gc)
 	gchar *u = gg_urlencode(gc->username);
 	gchar *p = gg_urlencode(gc->password);
 
-	GSList *gr = gc->groups;
+	GSList *gr = groups;
 
 	he->gc = gc;
 	he->type = AGG_HTTP_USERLIST_EXPORT;
@@ -1016,26 +1016,28 @@ static void export_buddies_server(struct gaim_connection *gc)
 		GSList *m = g->members;
 		while (m) {
 			struct buddy *b = m->data;
-			gchar *newdata;
-			/* GG Number */
-			gchar *name = gg_urlencode(b->name);
-			/* GG Pseudo */
-			gchar *show = gg_urlencode(strlen(b->show) ? b->show : b->name);
-			/* Group Name */
-			gchar *gname = gg_urlencode(g->name);
 
-			ptr = he->request;
-			newdata = g_strdup_printf("%s;%s;%s;%s;%s;%s;%s\r\n",
-						  show, show, show, show, "", gname, name);
-			he->request = g_strconcat(ptr, newdata, NULL);
+			if(b->user->gc == gc) {
+				gchar *newdata;
+				/* GG Number */
+				gchar *name = gg_urlencode(b->name);
+				/* GG Pseudo */
+				gchar *show = gg_urlencode(b->alias[0] ? b->alias : b->name);
+				/* Group Name */
+				gchar *gname = gg_urlencode(g->name);
 
-			g_free(newdata);
-			g_free(ptr);
+				ptr = he->request;
+				newdata = g_strdup_printf("%s;%s;%s;%s;%s;%s;%s\r\n",
+						show, show, show, show, "", gname, name);
+				he->request = g_strconcat(ptr, newdata, NULL);
 
-			g_free(gname);
-			g_free(show);
-			g_free(name);
+				g_free(newdata);
+				g_free(ptr);
 
+				g_free(gname);
+				g_free(show);
+				g_free(name);
+			}
 			m = g_slist_next(m);
 		}
 		gr = g_slist_next(gr);
@@ -1154,32 +1156,44 @@ static void agg_change_passwd(struct gaim_connection *gc, const char *old, const
 	}                                        
 }
 
-static void agg_do_action(struct gaim_connection *gc, char *action)
-{
-	if (!strcmp(action, _("Directory Search"))) {
-		show_find_info(gc);
-	} else if (!strcmp(action, _("Change Password"))) {
-		show_change_passwd(gc);
-	} else if (!strcmp(action, _("Import Buddy List from Server"))) {
-		import_buddies_server(gc);
-	} else if (!strcmp(action, _("Export Buddy List to Server"))) {
-		export_buddies_server(gc);
-	} else if (!strcmp(action, _("Delete Buddy List from Server"))) {
-	        delete_buddies_server(gc);
-	}
-}
-
-static GList *agg_actions()
+static GList *agg_actions(struct gaim_connection *gc)
 {
 	GList *m = NULL;
+	struct proto_actions_menu *pam;
+
+	pam = g_new0(struct proto_actions_menu, 1);
+	pam->label = _("Directory Search");
+	pam->callback = show_find_info;
+	pam->gc = gc;
+	m = g_list_append(m, pam);
 
-	m = g_list_append(m, _("Directory Search"));
 	m = g_list_append(m, NULL);
-	m = g_list_append(m, _("Change Password"));
+
+	pam = g_new0(struct proto_actions_menu, 1);
+	pam->label = _("Change Password");
+	pam->callback = show_change_passwd;
+	pam->gc = gc;
+	m = g_list_append(m, pam);
+
 	m = g_list_append(m, NULL);
-	m = g_list_append(m, _("Import Buddy List from Server"));
-	m = g_list_append(m, _("Export Buddy List to Server"));
-	m = g_list_append(m, _("Delete Buddy List from Server"));
+
+	pam = g_new0(struct proto_actions_menu, 1);
+	pam->label = _("Import Buddy List from Server");
+	pam->callback = import_buddies_server;
+	pam->gc = gc;
+	m = g_list_append(m, pam);
+
+	pam = g_new0(struct proto_actions_menu, 1);
+	pam->label = _("Export Buddy List to Server");
+	pam->callback = export_buddies_server;
+	pam->gc = gc;
+	m = g_list_append(m, pam);
+
+	pam = g_new0(struct proto_actions_menu, 1);
+	pam->label = _("Delete Buddy List from Server");
+	pam->callback = delete_buddies_server;
+	pam->gc = gc;
+	m = g_list_append(m, pam);
 
 	return m;
 }
@@ -1239,7 +1253,7 @@ static void agg_set_permit_deny_dummy(struct gaim_connection *gc)
 	/* It's implemented on client side because GG server doesn't support this */
 }
 
-static void agg_permit_deny_dummy(struct gaim_connection *gc, char *who)
+static void agg_permit_deny_dummy(struct gaim_connection *gc, const char *who)
 {
 	/* It's implemented on client side because GG server doesn't support this */
 }
@@ -1255,7 +1269,6 @@ G_MODULE_EXPORT void gg_init(struct prpl *ret)
 	ret->list_icon = agg_list_icon;
 	ret->away_states = agg_away_states;
 	ret->actions = agg_actions;
-	ret->do_action = agg_do_action;
 	ret->buddy_menu = agg_buddy_menu;
 	ret->chat_info = NULL;
 	ret->login = agg_login;
