@@ -29,6 +29,10 @@
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
+#include "gtkconv.h"
+#include "gtkutils.h"
+#include "stock.h"
+
 #define GAIM_DIALOG(x)	x = gtk_window_new(GTK_WINDOW_TOPLEVEL); \
 			gtk_window_set_type_hint(GTK_WINDOW(x), GDK_WINDOW_TYPE_HINT_DIALOG)
 #define GAIM_WINDOW_ICONIFIED(x) (gdk_window_get_state(GTK_WIDGET(x)->window) & GDK_WINDOW_STATE_ICONIFIED)
@@ -94,7 +98,8 @@ struct window_size {
 };
 
 /* struct buddy_chat went away and got merged with this. */
-struct conversation {
+#if 0
+struct gaim_conversation {
 	struct gaim_connection *gc;
 
 	/* stuff used for both IM and chat */
@@ -102,7 +107,7 @@ struct conversation {
 	char name[80];
 	GtkWidget *toolbar;
 	GtkWidget *text;
-	GtkWidget *entry;
+/*	GtkWidget *entry; */
 	GtkWidget *italic;
 	GtkWidget *bold;
 	GtkWidget *underline;
@@ -167,9 +172,9 @@ struct conversation {
         int id;
 	GtkWidget *count;
 	GtkWidget *list;
-	GtkWidget *whisper;
+	GtkWidget *whisper; 
 	GtkWidget *invite;
-	GtkWidget *close;
+	GtkWidget *close; 
 	GtkWidget *topic_text;
 
 	/* something to distinguish */
@@ -181,7 +186,13 @@ struct conversation {
 	guint32 icon_timer;
 	GdkPixbufAnimationIter *iter;
 	GtkWidget *save_icon;
+
+	GtkTextBuffer *entry_buffer;
+	GtkWidget     *entry;
+
+	GtkWidget *tab_label;
 };
+#endif
 
 struct log_conversation {
 	char name[80];
@@ -261,6 +272,17 @@ struct mod_user {
 	GtkWidget *register_user;
 };
 
+struct smiley_theme {
+	char *path;
+	char *name;
+	char *desc;
+	char *icon;
+	char *author;
+	
+	struct smiley_list *list;
+};
+
+
 #define EDIT_GC    0
 #define EDIT_GROUP 1
 #define EDIT_BUDDY 2
@@ -275,7 +297,8 @@ extern struct away_message *awaymessage;
 extern struct away_message *default_away;
 extern int auto_away;
 extern GtkWidget *awaymenu;
-extern GtkWidget *clistqueue; 
+extern GtkWidget *awayqueue;
+extern GtkListStore *awayqueuestore;
 
 /* Globals in buddy.c */
 extern GtkWidget *buddies;
@@ -284,12 +307,16 @@ extern GtkWidget *blist;
 extern int docklet_count;
 
 /* Globals in buddy_chat.c */
+#if 0
 extern GList *chats;	/* list of all chats (only use for tabbing!) */
 extern GtkWidget *all_chats;
 extern GtkWidget *joinchat;
+#endif
 
 /* Globals in conversation.c */
+#if 0
 extern GtkWidget *all_convos;
+#endif
 
 /* Globals in dialog.c */
 extern char fontface[128];
@@ -309,9 +336,17 @@ extern GtkWidget *fontseld;
 /* Globals in prpl.c */
 extern GtkWidget *protomenu;
 
+/* Globals in session.c */
+extern gboolean session_managed;
+
 /* Globals in sound.c */
 extern gboolean mute_sounds;
 
+/* Globals in themes.c */
+extern struct smiley_theme *current_smiley_theme;
+extern GSList *smiley_themes;
+
+
 /* Functions in about.c */
 extern void show_about(GtkWidget *, void *);
 extern void gaim_help(GtkWidget *, void *);
@@ -327,7 +362,7 @@ extern void do_away_menu();
 extern void away_list_unclicked(GtkWidget *, struct away_message *);
 extern void away_list_clicked(GtkWidget *, struct away_message *);
 extern void toggle_away_queue();
-extern void purge_away_queue(GSList*);
+extern void purge_away_queue(GSList**);
 
 /* Functions in browser.c */
 extern void open_url(GtkWidget *, char *);
@@ -348,9 +383,9 @@ extern void set_buddy(struct gaim_connection *, struct buddy *);
 extern void build_edit_tree();
 extern void do_bp_menu();
 extern void ui_add_buddy(struct gaim_connection *, struct group *, struct buddy *);
-extern void ui_remove_buddy(struct gaim_connection *, struct group *, struct buddy *);
-extern void ui_add_group(struct gaim_connection *, struct group *);
-extern void ui_remove_group(struct gaim_connection *, struct group *);
+extern void ui_remove_buddy(struct buddy *);
+extern void ui_add_group(struct group *);
+extern void ui_remove_group(struct group *);
 extern void toggle_buddy_pixmaps();
 extern void gaim_separator(GtkWidget *);
 extern void redo_buddy_list(); /* you really shouldn't call this function */
@@ -361,54 +396,44 @@ extern void docklet_add();
 extern void docklet_remove();
 extern void docklet_toggle();
 extern GtkWidget *gaim_new_item(GtkWidget *, const char *);
+extern void update_idle_times();
+extern void build_imchat_box(gboolean);
 
 /* Functions in buddy_chat.c */
-extern void join_chat();
-extern void chat_write(struct conversation *, char *, int, char *, time_t);
-extern void delete_chat(struct conversation *);
-extern void build_imchat_box(gboolean);
+#if 0
+extern void chat_write(struct gaim_conversation *, char *, int, char *, time_t);
+extern void delete_chat(struct gaim_conversation *);
 extern void update_chat_button_pix();
 extern void update_im_button_pix();
 extern void update_chat_tabs();
 extern void update_im_tabs();
-extern void update_idle_times();
 extern void do_join_chat();
+#endif
 
 /* Functions in conversation.c */
-extern void gaim_setup_imhtml(GtkWidget *);
-extern void update_convo_add_button(struct conversation *);
-extern void raise_convo_tab(struct conversation *);
-extern void set_convo_title(struct conversation *);
-extern void show_conv(struct conversation *);
-void set_convo_name(struct conversation *c, const char *nname);
-extern struct conversation *new_conversation(char *);
-extern void delete_conversation(struct conversation *);
-extern void surround(GtkWidget *, char *, char *);
+#if 0
+extern void update_convo_add_button(struct gaim_conversation *);
+extern void raise_convo_tab(struct gaim_conversation *);
+extern void set_convo_title(struct gaim_conversation *);
+extern void show_conv(struct gaim_conversation *);
+void set_convo_name(struct gaim_conversation *c, const char *nname);
+extern struct gaim_conversation *new_conversation(char *);
+extern void delete_conversation(struct gaim_conversation *);
+extern void surround(struct gaim_conversation *, char *, char *);
 extern int is_logging(char *);
 extern void set_state_lock(int);
-extern void rm_log(struct log_conversation *);
-extern struct log_conversation *find_log_info(char *);
-extern void remove_tags(GtkWidget *, char *);
-extern void update_log_convs();
+extern void remove_tags(struct gaim_conversation *, char *);
 extern void update_transparency();
 extern void update_font_buttons();
-extern void toggle_sensitive(GtkWidget *widget, GtkWidget *to_toggle);
-extern void do_bold(GtkWidget *, GtkWidget *);
-extern void do_italic(GtkWidget *, GtkWidget *);
-extern void do_underline(GtkWidget *, GtkWidget *);
-extern void do_strike(GtkWidget *, GtkWidget *);
-extern void do_small(GtkWidget *, GtkWidget *);
-extern void do_normal(GtkWidget *, GtkWidget *);
-extern void do_big(GtkWidget *, GtkWidget *);
-extern void set_font_face(char *, struct conversation *);
+extern void set_font_face(char *, struct gaim_conversation *);
 extern void redo_convo_menus();
 extern void convo_menu_remove(struct gaim_connection *);
 extern void remove_icon_data(struct gaim_connection *);
 extern void got_new_icon(struct gaim_connection *, char *);
 extern void toggle_spellchk();
-extern void set_convo_gc(struct conversation *, struct gaim_connection *);
-extern void update_buttons_by_protocol(struct conversation *);
-extern void toggle_fg_color(GtkWidget *, struct conversation *);
+extern void set_convo_gc(struct gaim_conversation *, struct gaim_connection *);
+extern void update_buttons_by_protocol(struct gaim_conversation *);
+extern void toggle_fg_color(GtkWidget *, struct gaim_conversation *);
 extern void toggle_smileys();
 extern void toggle_timestamps();
 extern void update_pixmaps();
@@ -419,10 +444,10 @@ extern void update_convo_color();
 extern void update_convo_font();
 extern void set_hide_icons();
 extern void set_convo_titles();
-extern void update_progress(struct conversation *, float);
-extern void update_convo_status(struct conversation *);
-extern gboolean reset_typing(char *);
+extern void update_progress(struct gaim_conversation *, float);
+extern void update_convo_status(struct gaim_conversation *);
 extern void set_anim();
+#endif
 
 /* Functions in dialogs.c */
 extern void alias_dialog_bud(struct buddy *);
@@ -439,22 +464,22 @@ extern void show_new_bp(char *, struct gaim_connection *, int, int, struct buddy
 extern void conv_show_log(GtkWidget *, gpointer);
 extern void chat_show_log(GtkWidget *, gpointer);
 extern void show_log(char *);
-extern void show_log_dialog(struct conversation *);
-extern void show_fgcolor_dialog(struct conversation *c, GtkWidget *color);
-extern void show_bgcolor_dialog(struct conversation *c, GtkWidget *color);
-extern void cancel_fgcolor(GtkWidget *widget, struct conversation *c);
-extern void cancel_bgcolor(GtkWidget *widget, struct conversation *c);
+extern void show_log_dialog(struct gaim_conversation *);
+extern void show_fgcolor_dialog(struct gaim_conversation *c, GtkWidget *color);
+extern void show_bgcolor_dialog(struct gaim_conversation *c, GtkWidget *color);
+extern void cancel_fgcolor(GtkWidget *widget, struct gaim_conversation *c);
+extern void cancel_bgcolor(GtkWidget *widget, struct gaim_conversation *c);
 extern void create_away_mess(GtkWidget *, void *);
 extern void show_ee_dialog(int);
-extern void show_add_link(GtkWidget *,struct conversation *);
-extern void show_smiley_dialog(struct conversation *, GtkWidget *);
-extern void close_smiley_dialog(GtkWidget *widget, struct conversation *c);
+extern void show_insert_link(GtkWidget *,struct gaim_conversation *);
+extern void show_smiley_dialog(struct gaim_conversation *, GtkWidget *);
+extern void close_smiley_dialog(GtkWidget *widget, struct gaim_conversation *c);
 extern void set_smiley_array(GtkWidget *widget, int smiley_type);
-extern void insert_smiley_text(GtkWidget *widget, struct conversation *c);
-extern void cancel_log(GtkWidget *, struct conversation *);
-extern void cancel_link(GtkWidget *, struct conversation *);
-extern void show_font_dialog(struct conversation *c, GtkWidget *font);
-extern void cancel_font(GtkWidget *widget, struct conversation *c);
+extern void insert_smiley_text(GtkWidget *widget, struct gaim_conversation *c);
+extern void cancel_log(GtkWidget *, struct gaim_conversation *);
+extern void cancel_link(GtkWidget *, struct gaim_conversation *);
+extern void show_font_dialog(struct gaim_conversation *c, GtkWidget *font);
+extern void cancel_font(GtkWidget *widget, struct gaim_conversation *c);
 extern void apply_font(GtkWidget *widget, GtkFontSelection *fontsel);
 extern void set_color_selection(GtkWidget *selection, GdkColor color);
 extern void show_rename_group(GtkWidget *, struct group *);
@@ -463,7 +488,7 @@ extern void load_perl_script();
 extern GtkWidget *picture_button(GtkWidget *, char *, char **);
 extern GtkWidget *picture_button2(GtkWidget *, char *, char **, short);
 extern GtkWidget *gaim_pixbuf_button(char *, char *, GaimButtonStyle);
-extern GtkWidget *gaim_pixbuf_button_from_stock(char *, char *, GaimButtonStyle);
+extern GtkWidget *gaim_pixbuf_button_from_stock(const char *, const char *, GaimButtonStyle);
 extern GtkWidget *gaim_pixbuf_toolbar_button_from_stock(char *);
 extern GtkWidget *gaim_pixbuf_toolbar_button_from_file(char *);
 extern int file_is_dir(const char *, GtkWidget *);
@@ -472,6 +497,7 @@ extern void show_privacy_options();
 extern void build_allow_list();
 extern void build_block_list();
 extern void destroy_fontsel(GtkWidget *w, gpointer d);
+extern void join_chat();
 
 /* Functions in multi.c */
 extern void account_editor(GtkWidget *, GtkWidget *);
@@ -500,7 +526,6 @@ extern void apply_font_dlg(GtkWidget *, GtkWidget *);
 extern void apply_color_dlg(GtkWidget *, gpointer);
 extern void destroy_colorsel(GtkWidget *, gpointer);
 
-
 /* Functions in prpl.c */
 extern void register_dialog();
 
@@ -508,10 +533,19 @@ extern void register_dialog();
 /* server.c is in desperate need need of a split */
 extern int find_queue_total_by_name(char *);
 
+/* Functions in session.c */
+extern void session_init(gchar *, gchar *);
+extern void session_end();
+
 /* Functions in sound.c */
 extern void play_sound(int);
 extern void play_file(char *);
 
+/* Functions in themes.c */
+extern void smiley_themeize(GtkWidget *);
+extern void smiley_theme_probe();
+extern struct smiley_theme *load_smiley_theme(const char *file, gboolean load);
+
 /* Fucnctions in util.c */
 extern GtkWidget *gaim_pixmap(char *, char *);
 extern GdkPixbuf *gaim_pixbuf(char *, char *);
